@@ -5,7 +5,7 @@ import grpc
 
 from pathlib import Path
 from configparser import ConfigParser
-from pkg_resources import get_distribution, DistributionNotFound
+from importlib.metadata import version, PackageNotFoundError
 
 # Enable prompt option for testing purposes
 prompt = False
@@ -153,15 +153,10 @@ class AuthInterceptor(grpc.UnaryUnaryClientInterceptor):
     def __init__(self, value):
         self.api_key = value
 
-    # def intercept_call(self, continuation, client_call_details, request_or_iterator):
-    #     client_version = get_distribution('dlubal.api').version
-    #     call_details = _ClientCallDetails(client_call_details, [("authorization", f"Bearer {self.api_key}"),("api-client-info", f"Python | {client_version}"),])
-    #     return continuation(call_details, request_or_iterator)
-
     def intercept_call(self, continuation, client_call_details, request_or_iterator):
         try:
-            client_version = get_distribution('dlubal.api').version
-        except DistributionNotFound:
+            client_version = version('dlubal.api')
+        except PackageNotFoundError:
             # Package not installed, fallback to default version string
             client_version = "dev"
 
