@@ -1,9 +1,12 @@
-from .block_pb2 import *
-from .intersection_pb2 import *
-from .line_release_pb2 import *
-from .nodal_release_pb2 import *
-from .rigid_link_pb2 import *
-from .structure_modification_pb2 import *
 from .surfaces_contact_pb2 import *
-from .surface_release_pb2 import *
+from .structure_modification_pb2 import *
+from .design_strip_pb2 import *
+from .design_strip_wizard_pb2 import *
+from .intersection_pb2 import *
 from .surface_results_adjustment_pb2 import *
+from .nodal_release_pb2 import *
+from .surface_release_pb2 import *
+from .surface_cell_pb2 import *
+from .block_pb2 import *
+from .line_release_pb2 import *
+from .rigid_link_pb2 import *
