@@ -22,7 +22,7 @@ with rfem.Application() as rfem_app:
 
     # Edit Block parameters:
     print("Parameters to set:")
-    parameters = rfem.structure_advanced.Block.ParametersTable()
+    parameters = rfem.structure_advanced.Block.ParametersTreeTable()
     common.set_tree_value(parameters, ['geometry', 'l'], 4.5)
     print(google.protobuf.json_format.MessageToJson(parameters))
 
